@@ -102,63 +102,43 @@ class LeCrapaud:
 
     def compare_experiment_scores(self, name: str):
         """Compare scores of experiments with matching names.
-        
+
         Args:
             name (str): Name or partial name of experiments to compare
-            
+
         Returns:
             dict: Dictionary containing experiment names as keys and their scores as values
         """
-        from lecrapaud.db import SessionLocal
-        from sqlalchemy.orm import joinedload
-        
-        db = SessionLocal()
-        try:
-            # Get all experiments with the given name pattern
-            experiments = (
-                db.query(Experiment)
-                .options(joinedload(Experiment.model_selections)
-                        .joinedload(ModelSelection.scores))
-                .filter(Experiment.name.ilike(f"%{name}%"))
-                .all()
-            )
-            
-            if not experiments:
-                return {"error": f"No experiments found with name containing '{name}'"}
-                
-            comparison = {}
-            
-            for exp in experiments:
-                scores = {
-                    "rmse": exp.avg_rmse,
-                    "logloss": exp.avg_logloss,
-                    "accuracy": None,
-                    "f1": None,
-                    "roc_auc": None
-                }
-                
-                # Get classification metrics from the first model selection with scores
-                for model_sel in exp.model_selections:
-                    if model_sel.scores:
-                        for score in model_sel.scores:
-                            if score.type == 'validation':  # Use validation scores
-                                if score.accuracy is not None:
-                                    scores["accuracy"] = score.accuracy
-                                if score.f1 is not None:
-                                    scores["f1"] = score.f1
-                                if score.roc_auc is not None:
-                                    scores["roc_auc"] = score.roc_auc
-                                break
-                
-                comparison[exp.name] = scores
-                
-            return comparison
-            
-        except Exception as e:
-            return {"error": f"Error comparing experiment scores: {str(e)}"}
-        finally:
-            db.close()
-    
+        # Get all experiments with the given name pattern
+        experiments = self.list_experiments(name=name)
+
+        if not experiments:
+            return {"error": f"No experiments found with name containing '{name}'"}
+
+        comparison = {}
+
+        for exp in experiments:
+            for model_sel in exp.experiment.model_selections:
+
+                if model_sel.best_score:
+
+                    scores = {
+                        "rmse": model_sel.best_score["rmse"],
+                        "logloss": model_sel.best_score["logloss"],
+                        "accuracy": model_sel.best_score["accuracy"],
+                        "f1": model_sel.best_score["f1"],
+                        "roc_auc": model_sel.best_score["roc_auc"],
+                    }
+                    target_name = model_sel.target.name
+
+                    comparison[exp.experiment.name][target_name] = scores
+                else:
+                    logger.warning(
+                        f"No best score found for experiment {exp.experiment.name} and target {model_sel.target.name}"
+                    )
+
+        return comparison
+
     def list_experiments(
         self, name: str = None, limit: int = 1000
     ) -> list["ExperimentEngine"]:
@@ -328,12 +308,12 @@ class ExperimentEngine:
     def feature_engineering(self, data, for_training=True):
         app = FeatureEngineeringEngine(
             data=data,
-            columns_drop=self.columns_drop,
-            columns_boolean=self.columns_boolean,
-            columns_date=self.columns_date,
-            columns_te_groupby=self.columns_te_groupby,
-            columns_te_target=self.columns_te_target,
-            for_training=for_training,
+            columns_drop=getattr(self, "columns_drop", []),
+            columns_boolean=getattr(self, "columns_boolean", []),
+            columns_date=getattr(self, "columns_date", []),
+            columns_te_groupby=getattr(self, "columns_te_groupby", []),
+            columns_te_target=getattr(self, "columns_te_target", []),
+            for_training=getattr(self, "for_training", True),
         )
         data = app.run()
         return data
@@ -341,19 +321,21 @@ class ExperimentEngine:
     def preprocess_feature(self, data, for_training=True):
         app = PreprocessFeature(
             data=data,
-            experiment=self.experiment,
-            time_series=self.time_series,
-            date_column=self.date_column,
-            group_column=self.group_column,
-            val_size=self.val_size,
-            test_size=self.test_size,
-            columns_pca=self.columns_pca,
-            columns_onehot=self.columns_onehot,
-            columns_binary=self.columns_binary,
-            columns_frequency=self.columns_frequency,
-            columns_ordinal=self.columns_ordinal,
-            target_numbers=self.target_numbers,
-            target_clf=self.target_clf,
+            experiment=getattr(self, "experiment", None),
+            time_series=getattr(self, "time_series", False),
+            date_column=getattr(self, "date_column", None),
+            group_column=getattr(self, "group_column", None),
+            val_size=getattr(self, "val_size", 0.2),
+            test_size=getattr(self, "test_size", 0.2),
+            columns_pca=getattr(self, "columns_pca", []),
+            pca_temporal=getattr(self, "pca_temporal", []),
+            pca_cross_sectional=getattr(self, "pca_cross_sectional", []),
+            columns_onehot=getattr(self, "columns_onehot", []),
+            columns_binary=getattr(self, "columns_binary", []),
+            columns_ordinal=getattr(self, "columns_ordinal", []),
+            columns_frequency=getattr(self, "columns_frequency", []),
+            target_numbers=getattr(self, "target_numbers", []),
+            target_clf=getattr(self, "target_clf", []),
         )
         if for_training:
             train, val, test = app.run()
@@ -385,14 +367,14 @@ class ExperimentEngine:
             train=train,
             val=val,
             test=test,
-            experiment=self.experiment,
-            target_numbers=self.target_numbers,
-            target_clf=self.target_clf,
-            models_idx=self.models_idx,
-            time_series=self.time_series,
-            max_timesteps=self.max_timesteps,
-            date_column=self.date_column,
-            group_column=self.group_column,
+            experiment=getattr(self, "experiment", None),
+            target_numbers=getattr(self, "target_numbers", []),
+            target_clf=getattr(self, "target_clf", []),
+            models_idx=getattr(self, "models_idx", []),
+            time_series=getattr(self, "time_series", False),
+            max_timesteps=getattr(self, "max_timesteps", 120),
+            date_column=getattr(self, "date_column", None),
+            group_column=getattr(self, "group_column", None),
         )
         if for_training:
             data, reshaped_data = app.run()
@@ -407,13 +389,13 @@ class ExperimentEngine:
                 data=data,
                 reshaped_data=reshaped_data,
                 target_number=target_number,
-                experiment=self.experiment,
-                target_clf=self.target_clf,
-                models_idx=self.models_idx,
-                time_series=self.time_series,
-                date_column=self.date_column,
-                group_column=self.group_column,
-                target_clf_thresholds=self.target_clf_thresholds,
+                experiment=getattr(self, "experiment", None),
+                target_clf=getattr(self, "target_clf", []),
+                models_idx=getattr(self, "models_idx", []),
+                time_series=getattr(self, "time_series", False),
+                date_column=getattr(self, "date_column", None),
+                group_column=getattr(self, "group_column", None),
+                target_clf_thresholds=getattr(self, "target_clf_thresholds", {}),
             )
             if best_params and target_number not in best_params.keys():
                 raise ValueError(
