@@ -11,6 +11,7 @@ from sqlalchemy import (
 from sqlalchemy import func
 from sqlalchemy.orm import relationship
 from lecrapaud.db.models.base import Base
+from lecrapaud.config import LECRAPAUD_TABLE_PREFIX
 
 
 class Score(Base):
@@ -50,7 +51,7 @@ class Score(Base):
     f1_at_threshold = Column(Float)
     model_training_id = Column(
         BigInteger,
-        ForeignKey("lecrapaud_model_trainings.id", ondelete="CASCADE"),
+        ForeignKey(f"{LECRAPAUD_TABLE_PREFIX}_model_trainings.id", ondelete="CASCADE"),
         nullable=False,
     )
 
