@@ -1,12 +1,16 @@
-import os, shutil
-from pathlib import Path
+import os
+import shutil
+from lecrapaud.config import LECRAPAUD_LOGFILE
 
 cwd = os.getcwd()
-tmp_dir = cwd + "/tmp"
-logger_dir = cwd + "/log"
 
+tmp_dir = cwd + "/tmp"
 os.makedirs(tmp_dir, exist_ok=True)
-os.makedirs(logger_dir, exist_ok=True)
+
+logger_dir = None
+if LECRAPAUD_LOGFILE:
+    logger_dir = os.path.join(cwd, LECRAPAUD_LOGFILE)
+    os.makedirs(logger_dir, exist_ok=True)
 
 
 def clean_directories():
