@@ -1093,6 +1093,7 @@ class ModelSelectionEngine:
             best_model_params = json.load(f)[best_model_name]
 
         # Save model_selection results to db
+
         model_selection = ModelSelection.get(model_selection.id)
         model_selection.best_model_id = Model.find_by(
             name=best_score_overall["MODEL_NAME"], type=self.target_type
@@ -1100,6 +1101,17 @@ class ModelSelectionEngine:
         model_selection.best_model_params = best_model_params
         model_selection.best_thresholds = best_thresholds
         model_selection.best_model_path = best_model_path
+
+        drop_cols = [
+            "DATE",
+            "MODEL_NAME",
+            "MODEL_PATH",
+        ]
+        best_score_overall = {
+            k: v for k, v in best_score_overall.items() if k not in drop_cols
+        }
+        score_data = {k.lower(): v for k, v in best_score_overall.items()}
+        model_selection.best_score = score_data
         model_selection.save()
 
         logger.info(f"Best model overall is : {best_score_overall}")
@@ -1781,7 +1793,17 @@ def find_best_threshold(
                     logger.warning(
                         f"[Class {cls}] No threshold with precision ≥ {target_value}"
                     )
-                    best_idx = int(np.argmax(precision))  # fallback
+                    # fallback: meilleure precision parmi ceux avec recall>0
+                    cand = np.where(recall > 0)[0]
+                    if cand.size:
+                        best_idx = cand[int(np.argmax(precision[cand]))]
+                        logger.warning(
+                            f"[Class {cls}] Fallback to best precision with recall>0: "
+                            f"idx={best_idx}, precision={precision[best_idx]:.4f}, recall={recall[best_idx]:.4f}"
+                        )
+                    else:
+                        logger.error(f"[Class {cls}] No threshold achieves recall>0.")
+                        best_idx = None
 
             elif metric == "f1":
                 valid_indices = [i for i, val in enumerate(f1) if val >= target_value]
@@ -1795,6 +1817,15 @@ def find_best_threshold(
         else:
             best_idx = int(np.argmax(values))  # no constraint, get best value
 
+        if best_idx is None:
+            results[cls_str] = {
+                "threshold": None,
+                "precision": None,
+                "recall": None,
+                "f1": None,
+            }
+            continue
+
         results[cls_str] = {
             "threshold": float(thresholds[best_idx]),
             "precision": float(precision[best_idx]),
